.. include:: ./refs.rst

.. raw:: html

   <link rel="stylesheet" type="text/css" href="_static/showcase.css">

========
Showcase
========

These packages provide management commands that have been implemented using django-typer_. If you
would like us to showcase a package,
`please submit a PR <https://github.com/django-commons/django-typer>`_.

.. note::

   The following packages are not maintained by the django-typer_ project. If you have any issues
   with the packages, please contact the package maintainers.

----------------

.. list-table::
   :header-rows: 1

   * - Package
     - Description
   * - `django-tailwind-cli <https://pypi.org/project/django-tailwind-cli>`_
     - Django and Tailwind integration based on the prebuilt Tailwind CSS CLI.
   * - `django-render-static <https://pypi.org/project/django-render-static>`_
     - Use Django's template engines to render static files at deployment or package time. Includes
       transpilers for extending Django's url reversal and enums to JavaScript.
   * - `django-routines <https://pypi.org/project/django-routines>`_
     - Define named sequences of management commands in Django settings files for batched execution.
